@@ -434,7 +434,7 @@ class Info(FollowerComponent):
     def __init__(self, app_id, version, is_essential=False, depends=None,
                  name=None, icon=None, icon_filename=None,
                  short_description=None, description=None, manual_page=None,
-                 clients=None, donation_url=None):
+                 clients=None, donation_url=None, tags=None):
         """Store the basic properties of an app as a component.
 
         Each app must contain at least one component of this type to provide
@@ -504,6 +504,9 @@ class Info(FollowerComponent):
         'donation_url' is a link to a webpage that describes how to
         donate to the upstream project.
 
+        'tags' is a list of tags that describe the app. Tags help users to find
+        similar apps or alternatives and discover use cases.
+
         """
         self.component_id = app_id + '-info'
         self.app_id = app_id
@@ -518,9 +521,32 @@ class Info(FollowerComponent):
         self.manual_page = manual_page
         self.clients = clients
         self.donation_url = donation_url
+        self._tags = tags or []
         if clients:
             clients_module.validate(clients)
 
+    @property
+    def tags(self) -> list[str]:
+        """Return a list of untranslated tags on the app.
+
+        These can only be retrieved after Django has been configured.
+        """
+        # Store untranslated original strings instead of proxy objects
+        from django.utils.translation import override
+        with override(language=None):
+            return [str(tag) for tag in self._tags]
+
+    @classmethod
+    def list_tags(self) -> list[str]:
+        """Return a list of untranslated tags."""
+        tags: set[str] = set()
+        from django.utils.translation import override
+        with override(language=None):
+            for app in App.list():
+                tags.update((str(tag) for tag in app.info.tags))
+
+        return list(tags)
+
 
 class EnableState(LeaderComponent):
     """A component to hold the enable state of an app using a simple flag.
@@ -626,8 +652,8 @@ def _initialize_module(module_name, module):
         for app_class in app_classes:
             app_class()
     except Exception as exception:
-        logger.exception('Exception while running init for %s: %s', module,
-                         exception)
+        logger.exception('Exception while running init for module %s: %s',
+                         module_name, exception)
         if cfg.develop:
             raise
 
