@@ -18,7 +18,7 @@ from plinth.diagnostic_check import (DiagnosticCheck,
 from plinth.package import Packages
 from plinth.privileged import service as service_privileged
 
-from . import privileged
+from . import manifest, privileged
 from .components import UsersAndGroups
 
 first_boot_steps = [
@@ -47,7 +47,7 @@ class UsersApp(app_module.App):
 
     app_id = 'users'
 
-    _version = 7
+    _version = 8
 
     can_be_disabled = False
 
@@ -58,7 +58,7 @@ class UsersApp(app_module.App):
         info = app_module.Info(app_id=self.app_id, version=self._version,
                                is_essential=True, name=_('Users and Groups'),
                                icon='fa-users', description=_description,
-                               manual_page='Users')
+                               manual_page='Users', tags=manifest.tags)
         self.add(info)
 
         menu_item = menu.Menu('menu-users', info.name, None, info.icon,
