@@ -6,12 +6,14 @@ Main FreedomBox views.
 import datetime
 import random
 import time
+import traceback
 import urllib.parse
 
 from django.contrib import messages
 from django.core.exceptions import ImproperlyConfigured
 from django.forms import Form
-from django.http import Http404, HttpResponseBadRequest, HttpResponseRedirect
+from django.http import (Http404, HttpRequest, HttpResponseBadRequest,
+                         HttpResponseRedirect)
 from django.shortcuts import redirect
 from django.template.response import TemplateResponse
 from django.urls import reverse
@@ -62,23 +64,73 @@ def is_safe_url(url):
     return True
 
 
+def get_breadcrumbs(request: HttpRequest) -> dict[str, dict[str, str | bool]]:
+    """Return all the URL ancestors that can be show as breadcrumbs."""
+    breadcrumbs = {}
+
+    def _add(url: str, name: str, url_name: str | None = None):
+        """Add item into the breadcrumb dictionary."""
+        breadcrumbs[url] = {
+            'name': name,
+            'is_active': request.path == url,
+            'url_name': url_name
+        }
+
+    url_name = request.resolver_match.url_name
+    full_url_name = ':'.join(request.resolver_match.app_names + [url_name])
+    try:
+        menu_item = menu.Menu.get_with_url_name(full_url_name)
+    except LookupError:
+        # There is no menu entry for this page, find it's app.
+        _add(request.path, _('Here'), full_url_name)
+        app_url_name = ':'.join(request.resolver_match.app_names + ['index'])
+        try:
+            menu_item = menu.Menu.get_with_url_name(app_url_name)
+        except LookupError:
+            # Don't know which app this page belongs to, assume parent is Home.
+            menu_item = menu.Menu.get_with_url_name('index')
+
+    for _number in range(10):
+        _add(menu_item.url, menu_item.name, menu_item.url_name)
+        if not menu_item.parent_url_name:
+            # We have reached the top
+            break
+
+        menu_item = menu.Menu.get_with_url_name(menu_item.parent_url_name)
+    else:
+        # Too much hierarchy, we must be in a recursive loop.
+        breadcrumbs = {}
+        menu_item = menu.Menu.get_with_url_name('index')
+        _add(menu_item.url, menu_item.name, menu_item.url_name)
+
+    # Find the active section: 'index', 'apps', 'system' or 'help'.
+    active_section_index = -2 if len(breadcrumbs) >= 2 else -1
+    active_section_key = list(breadcrumbs.keys())[active_section_index]
+    breadcrumbs[active_section_key]['is_active_section'] = True
+
+    return breadcrumbs
+
+
 def messages_error(request, message, exception):
     """Show an error message using Django messages framework.
 
     If an exception can show HTML message, handle is separately.
     """
     if hasattr(exception, 'get_html_message'):
-        collapse_id = 'error-details-' + str(random.randint(0, 10**9))
-        message = format_html(
-            '{message} <a href="#" class="dropdown-toggle" '
-            'data-toggle="collapse" data-target="#{collapse_id}" '
-            'aria-expanded="false" aria-controls="{collapse_id}">'
-            'Details</a><pre class="collapse" '
-            'id="{collapse_id}"><code>{html_message}</code></pre>',
-            message=message, html_message=exception.get_html_message(),
-            collapse_id=collapse_id)
+        html_message = exception.get_html_message()
+    else:
+        exception_lines = traceback.format_exception(exception)
+        html_message = ''.join(exception_lines)
 
-    messages.error(request, message)
+    collapse_id = 'error-details-' + str(random.randint(0, 10**9))
+    formatted_message = format_html(
+        '{message} <a href="#" class="dropdown-toggle" '
+        'data-bs-toggle="collapse" data-bs-target="#{collapse_id}" '
+        'aria-expanded="false" aria-controls="{collapse_id}">'
+        'Details</a><pre class="collapse" '
+        'id="{collapse_id}"><code>{html_message}</code></pre>',
+        message=message, html_message=html_message, collapse_id=collapse_id)
+    messages.error(request, formatted_message)
 
 
 def _get_redirect_url_from_param(request):
@@ -568,9 +620,8 @@ def notification_dismiss(request, id):
     """Dismiss a notification."""
     from .notification import Notification
     notes = Notification.list(key=id, user=request.user)
-    if not notes:
-        raise Http404
-
-    notes[0].dismiss()
+    if notes:
+        # If a notification is not found, no need to dismiss it.
+        notes[0].dismiss()
 
     return HttpResponseRedirect(_get_redirect_url_from_param(request))
